@@ -133,7 +133,13 @@ class QA:
         logger.debug(json.dumps(r.json(), indent=2))
 
     def _create(self):
-        qa_default_name = f"{git.get_username()}_{self._git.current_branch_name()}"
+        if "staging" in self._qainit.url:
+            qa_default_name = (
+                f"staging_{git.get_username()}_{self._git.current_branch_name()}"
+            )
+        else:
+            qa_default_name = f"{git.get_username()}_{self._git.current_branch_name()}"
+
         qa_name = prompt_utils.ask_questions_input(
             "Choose the QA name: ", default_text=qa_default_name
         )
