@@ -40,7 +40,7 @@ class QainitHandler:
     def __init__(self, config, tokens):
         self._token = tokens.drone
         self._config = config
-        self.qainit_url = self._config.qainit["url"]
+        self.url = self._config.qainit["url"]
         self.auth0_token = self._config.get_cache("auth0_token")
         self._github = GithubHandler(tokens)
 
@@ -86,7 +86,7 @@ class QainitHandler:
         return srv_list
 
     def execute(self, request_method, api_endpoint, body=None):
-        api_url = self._config.qainit["url"] + api_endpoint
+        api_url = self.url + api_endpoint
         auth0_token = self._config.get_cache("auth0_token")
 
         headers = {
